==> igniteui-angular-charts-18.2.0.tgz: package/esm2015/lib/FastStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { FastStochasticOscillatorIndicatorStrategy } from "./FastStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let FastStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class FastStochasticOscillatorIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        bj() {
            return new FastStochasticOscillatorIndicator();
        }
        get_abv() {
            return new FastStochasticOscillatorIndicatorStrategy();
        }
        get abv() {
            return this.get_abv();
        }
        get_ab8() {
            return FastStochasticOscillatorIndicator.$;
        }
        get ab8() {
            return this.get_ab8();
        }
        get acg() {
            return typeGetValue(this.c(FastStochasticOscillatorIndicator.ach));
        }
        set acg(a) {
            this.h(FastStochasticOscillatorIndicator.ach, a);
        }
        ab1() {
            return this.acg;
        }
        aca(a) {
            this.acg = a;
        }
    }
    FastStochasticOscillatorIndicator.$t = markType(FastStochasticOscillatorIndicator, 'FastStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    FastStochasticOscillatorIndicator.ach = StrategyBasedIndicator.acd(14, FastStochasticOscillatorIndicator.$);
    return FastStochasticOscillatorIndicator;
})();

==> igniteui-angular-charts-20.0.0.tgz: package/esm2015/lib/FastStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { FastStochasticOscillatorIndicatorStrategy } from "./FastStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let FastStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class FastStochasticOscillatorIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        bk() {
            return new FastStochasticOscillatorIndicator();
        }
        get_ab0() {
            return new FastStochasticOscillatorIndicatorStrategy();
        }
        get ab0() {
            return this.get_ab0();
        }
        get_acd() {
            return FastStochasticOscillatorIndicator.$;
        }
        get acd() {
            return this.get_acd();
        }
        get acl() {
            return typeGetValue(this.c(FastStochasticOscillatorIndicator.acm));
        }
        set acl(a) {
            this.h(FastStochasticOscillatorIndicator.acm, a);
        }
        ab6() {
            return this.acl;
        }
        acf(a) {
            this.acl = a;
        }
    }
    FastStochasticOscillatorIndicator.$t = markType(FastStochasticOscillatorIndicator, 'FastStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    FastStochasticOscillatorIndicator.acm = StrategyBasedIndicator.aci(14, FastStochasticOscillatorIndicator.$);
    return FastStochasticOscillatorIndicator;
})();
